@@ -37,13 +37,13 @@ class Listener:
 
     def record_event(self, event: Event):
         sql = '''
-            INSERT INTO uploads(event_id,timestamp,parent_id,path,item_name,full_name,email)
+            INSERT INTO events(event_id,timestamp,parent_id,path,item_name,full_name,email)
             VALUES(?,?,?,?,?,?,?)  
             '''
         self.cursor.execute(sql, event.sql)
     
     def event_recorded(self, event: Event):
-        sql = f"SELECT count(*) FROM uploads WHERE event_id = ?"
+        sql = f"SELECT count(*) FROM events WHERE event_id = ?"
         self.cursor.execute(sql, (event.event_id,))
         data = self.cursor.fetchone()[0]
         return data != 0
@@ -51,9 +51,9 @@ class Listener:
     def run(self) -> None:
         for event in self.events:
             if self.event_recorded(event):
-                logger.debug(f"Skipping already processed file: {event.upload_file_name}")
+                logger.debug(f"Skipping already processed event: {event.event_item_name}")
                 continue
-            logger.info(f"Processing file: {event.upload_file_name}")
+            logger.info(f"Processing event: {event.event_item_name}")
             self.record_event(event)
             if (callback := self.callback):
                 callback(
